==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/pipes/kotlin/outputs/PipeSourceParametersSelfManagedKafkaParametersCredentials.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.pipes.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property basicAuth The ARN of the Secrets Manager secret containing the credentials.
 * @property clientCertificateTlsAuth The ARN of the Secrets Manager secret containing the credentials.
 * @property saslScram256Auth The ARN of the Secrets Manager secret containing the credentials.
 * @property saslScram512Auth The ARN of the Secrets Manager secret containing the credentials.
 */
public data class PipeSourceParametersSelfManagedKafkaParametersCredentials(
    public val basicAuth: String,
    public val clientCertificateTlsAuth: String? = null,
    public val saslScram256Auth: String? = null,
    public val saslScram512Auth: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.pipes.outputs.PipeSourceParametersSelfManagedKafkaParametersCredentials):
            PipeSourceParametersSelfManagedKafkaParametersCredentials =
            PipeSourceParametersSelfManagedKafkaParametersCredentials(
                basicAuth = javaType.basicAuth(),
                clientCertificateTlsAuth = javaType.clientCertificateTlsAuth().map({ args0 -> args0 }).orElse(null),
                saslScram256Auth = javaType.saslScram256Auth().map({ args0 -> args0 }).orElse(null),
                saslScram512Auth = javaType.saslScram512Auth().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/pipes/kotlin/outputs/PipeSourceParametersSelfManagedKafkaParametersCredentials.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.pipes.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property basicAuth The ARN of the Secrets Manager secret containing the credentials.
 * @property clientCertificateTlsAuth The ARN of the Secrets Manager secret containing the credentials.
 * @property saslScram256Auth The ARN of the Secrets Manager secret containing the credentials.
 * @property saslScram512Auth The ARN of the Secrets Manager secret containing the credentials.
 */
public data class PipeSourceParametersSelfManagedKafkaParametersCredentials(
    public val basicAuth: String? = null,
    public val clientCertificateTlsAuth: String? = null,
    public val saslScram256Auth: String? = null,
    public val saslScram512Auth: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.pipes.outputs.PipeSourceParametersSelfManagedKafkaParametersCredentials): PipeSourceParametersSelfManagedKafkaParametersCredentials =
            PipeSourceParametersSelfManagedKafkaParametersCredentials(
                basicAuth = javaType.basicAuth().map({ args0 -> args0 }).orElse(null),
                clientCertificateTlsAuth = javaType.clientCertificateTlsAuth().map({ args0 -> args0 }).orElse(null),
                saslScram256Auth = javaType.saslScram256Auth().map({ args0 -> args0 }).orElse(null),
                saslScram512Auth = javaType.saslScram512Auth().map({ args0 -> args0 }).orElse(null),
            )
    }
}
